@@ -170,8 +170,13 @@ class SOCol(object):
         # True: a CASCADE constraint is generated
         # False: a RESTRICT constraint is generated
         # 'null': a SET NULL trigger is generated
-        if isinstance(cascade, str):
-            assert cascade == 'null', (
+        if not isinstance(cascade, (bool, string_type, type(None))):
+            raise TypeError(
+                'Expected cascade to be True, False, None or "null", '
+                "(you gave: %r %r)" % (type(cascade), cascade)
+            )
+        if isinstance(cascade, str) and (cascade != 'null'):
+            raise ValueError(
                 "The only string value allowed for cascade is 'null' "
                 "(you gave: %r)" % cascade)
         self.cascade = cascade
@@ -1505,7 +1510,10 @@ class TimeValidator(DateTimeValidator):
                 raise validators.Invalid(
                     "the value for the TimeCol '%s' must has days=0, "
                     "it has days=%d" % (self.name, value.days), value, state)
-            return datetime.time(*time.gmtime(value.seconds)[3:6])
+            return datetime.time(
+                *time.gmtime(value.seconds)[3:6],
+                microsecond=value.microseconds
+            )
         value = super(TimeValidator, self).to_python(value, state)
         if isinstance(value, datetime.datetime):
             value = value.time()
